function x=Njutn(x0,y,tol)
%Funkcija x=Njutn(x0,y,tol) odredjuje resenje
%nelinearne jednacine f(x)=y koriscenjem Njutnove
%metode.
%
%Ulazni argumenti su:
%     x0 - pocetna vrednost iterativnog niza
%     y - desna strana jednacine f(x)=y
%     tol - tacnost
%
%Izlazni argument:
%     x - vrednost argumenta za koju je f(x)=y
%
%Pomocni fajl:
%     funkcija.m - sadrzi anonimnu funkciju f
%
funkcija

F=sym(f);%konvertujemo funkciju u simbolicku
F1=diff(F);%izvod simbolicke funkcije
f1=matlabFunction(F1);%konvertujemo simbolicku funkciju F1 u anonimnu funkciju

f=@(x) f(x)-y;

iter=0;
while iter<100
    x1=x0-f(x0)/f1(x0);
    iter=iter+1;
    if abs(x1-x0)<tol
        break;
    end
    x0=x1;
end
x=x1;
if iter==100
    disp('Dostignut je maksimalan broj iteracija.')
end

    